# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.dydxprotocol.blocktime import query_pb2 as dydxprotocol_dot_blocktime_dot_query__pb2

GRPC_GENERATED_VERSION = '1.75.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in dydxprotocol/blocktime/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DowntimeParams = channel.unary_unary(
                '/dydxprotocol.blocktime.Query/DowntimeParams',
                request_serializer=dydxprotocol_dot_blocktime_dot_query__pb2.QueryDowntimeParamsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_blocktime_dot_query__pb2.QueryDowntimeParamsResponse.FromString,
                _registered_method=True)
        self.PreviousBlockInfo = channel.unary_unary(
                '/dydxprotocol.blocktime.Query/PreviousBlockInfo',
                request_serializer=dydxprotocol_dot_blocktime_dot_query__pb2.QueryPreviousBlockInfoRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_blocktime_dot_query__pb2.QueryPreviousBlockInfoResponse.FromString,
                _registered_method=True)
        self.AllDowntimeInfo = channel.unary_unary(
                '/dydxprotocol.blocktime.Query/AllDowntimeInfo',
                request_serializer=dydxprotocol_dot_blocktime_dot_query__pb2.QueryAllDowntimeInfoRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_blocktime_dot_query__pb2.QueryAllDowntimeInfoResponse.FromString,
                _registered_method=True)
        self.SynchronyParams = channel.unary_unary(
                '/dydxprotocol.blocktime.Query/SynchronyParams',
                request_serializer=dydxprotocol_dot_blocktime_dot_query__pb2.QuerySynchronyParamsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_blocktime_dot_query__pb2.QuerySynchronyParamsResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def DowntimeParams(self, request, context):
        """Queries the DowntimeParams.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreviousBlockInfo(self, request, context):
        """Queries the information of the previous block
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllDowntimeInfo(self, request, context):
        """Queries all recorded downtime info.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SynchronyParams(self, request, context):
        """Queries the SynchronyParams.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DowntimeParams': grpc.unary_unary_rpc_method_handler(
                    servicer.DowntimeParams,
                    request_deserializer=dydxprotocol_dot_blocktime_dot_query__pb2.QueryDowntimeParamsRequest.FromString,
                    response_serializer=dydxprotocol_dot_blocktime_dot_query__pb2.QueryDowntimeParamsResponse.SerializeToString,
            ),
            'PreviousBlockInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.PreviousBlockInfo,
                    request_deserializer=dydxprotocol_dot_blocktime_dot_query__pb2.QueryPreviousBlockInfoRequest.FromString,
                    response_serializer=dydxprotocol_dot_blocktime_dot_query__pb2.QueryPreviousBlockInfoResponse.SerializeToString,
            ),
            'AllDowntimeInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.AllDowntimeInfo,
                    request_deserializer=dydxprotocol_dot_blocktime_dot_query__pb2.QueryAllDowntimeInfoRequest.FromString,
                    response_serializer=dydxprotocol_dot_blocktime_dot_query__pb2.QueryAllDowntimeInfoResponse.SerializeToString,
            ),
            'SynchronyParams': grpc.unary_unary_rpc_method_handler(
                    servicer.SynchronyParams,
                    request_deserializer=dydxprotocol_dot_blocktime_dot_query__pb2.QuerySynchronyParamsRequest.FromString,
                    response_serializer=dydxprotocol_dot_blocktime_dot_query__pb2.QuerySynchronyParamsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.blocktime.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('dydxprotocol.blocktime.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def DowntimeParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.blocktime.Query/DowntimeParams',
            dydxprotocol_dot_blocktime_dot_query__pb2.QueryDowntimeParamsRequest.SerializeToString,
            dydxprotocol_dot_blocktime_dot_query__pb2.QueryDowntimeParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PreviousBlockInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.blocktime.Query/PreviousBlockInfo',
            dydxprotocol_dot_blocktime_dot_query__pb2.QueryPreviousBlockInfoRequest.SerializeToString,
            dydxprotocol_dot_blocktime_dot_query__pb2.QueryPreviousBlockInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AllDowntimeInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.blocktime.Query/AllDowntimeInfo',
            dydxprotocol_dot_blocktime_dot_query__pb2.QueryAllDowntimeInfoRequest.SerializeToString,
            dydxprotocol_dot_blocktime_dot_query__pb2.QueryAllDowntimeInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SynchronyParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.blocktime.Query/SynchronyParams',
            dydxprotocol_dot_blocktime_dot_query__pb2.QuerySynchronyParamsRequest.SerializeToString,
            dydxprotocol_dot_blocktime_dot_query__pb2.QuerySynchronyParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/crisis/module/v1/module.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/crisis/module/v1/module.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/crisis/module/v1/module.proto\x12\x17\x63osmos.crisis.module.v1\x1a cosmos/app/v1alpha1/module.proto\"f\n\x06Module\x12\x1a\n\x12\x66\x65\x65_collector_name\x18\x01 \x01(\t\x12\x11\n\tauthority\x18\x02 \x01(\t:-\xba\xc0\x96\xda\x01\'\n%github.com/cosmos/cosmos-sdk/x/crisisb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crisis.module.v1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001\'\n%github.com/cosmos/cosmos-sdk/x/crisis'
  _globals['_MODULE']._serialized_start=99
  _globals['_MODULE']._serialized_end=201
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/delaymsg/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/delaymsg/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/delaymsg/tx.proto\x12\x15\x64ydxprotocol.delaymsg\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19google/protobuf/any.proto\"\x87\x01\n\x0fMsgDelayMessage\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12!\n\x03msg\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x14\n\x0c\x64\x65lay_blocks\x18\x03 \x01(\r:\x0e\x82\xe7\xb0*\tauthority\"%\n\x17MsgDelayMessageResponse\x12\n\n\x02id\x18\x01 \x01(\x04\x32m\n\x03Msg\x12\x66\n\x0c\x44\x65layMessage\x12&.dydxprotocol.delaymsg.MsgDelayMessage\x1a..dydxprotocol.delaymsg.MsgDelayMessageResponseB<Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.delaymsg.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/types'
  _globals['_MSGDELAYMESSAGE'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGDELAYMESSAGE'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGDELAYMESSAGE']._loaded_options = None
  _globals['_MSGDELAYMESSAGE']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGDELAYMESSAGE']._serialized_start=137
  _globals['_MSGDELAYMESSAGE']._serialized_end=272
  _globals['_MSGDELAYMESSAGERESPONSE']._serialized_start=274
  _globals['_MSGDELAYMESSAGERESPONSE']._serialized_end=311
  _globals['_MSG']._serialized_start=313
  _globals['_MSG']._serialized_end=422
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.perpetuals import params_pb2 as _params_pb2
from v4_proto.dydxprotocol.perpetuals import perpetual_pb2 as _perpetual_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgCreatePerpetual(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _perpetual_pb2.PerpetualParams
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_perpetual_pb2.PerpetualParams, _Mapping]] = ...) -> None: ...

class MsgCreatePerpetualResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgSetLiquidityTier(_message.Message):
    __slots__ = ("authority", "liquidity_tier")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    LIQUIDITY_TIER_FIELD_NUMBER: _ClassVar[int]
    authority: str
    liquidity_tier: _perpetual_pb2.LiquidityTier
    def __init__(self, authority: _Optional[str] = ..., liquidity_tier: _Optional[_Union[_perpetual_pb2.LiquidityTier, _Mapping]] = ...) -> None: ...

class MsgSetLiquidityTierResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdatePerpetualParams(_message.Message):
    __slots__ = ("authority", "perpetual_params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PERPETUAL_PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    perpetual_params: _perpetual_pb2.PerpetualParams
    def __init__(self, authority: _Optional[str] = ..., perpetual_params: _Optional[_Union[_perpetual_pb2.PerpetualParams, _Mapping]] = ...) -> None: ...

class MsgUpdatePerpetualParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class FundingPremium(_message.Message):
    __slots__ = ("perpetual_id", "premium_ppm")
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    PREMIUM_PPM_FIELD_NUMBER: _ClassVar[int]
    perpetual_id: int
    premium_ppm: int
    def __init__(self, perpetual_id: _Optional[int] = ..., premium_ppm: _Optional[int] = ...) -> None: ...

class MsgAddPremiumVotes(_message.Message):
    __slots__ = ("votes",)
    VOTES_FIELD_NUMBER: _ClassVar[int]
    votes: _containers.RepeatedCompositeFieldContainer[FundingPremium]
    def __init__(self, votes: _Optional[_Iterable[_Union[FundingPremium, _Mapping]]] = ...) -> None: ...

class MsgAddPremiumVotesResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateParams(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _params_pb2.Params
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class MsgUpdateParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/revshare/revshare.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/revshare/revshare.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$dydxprotocol/revshare/revshare.proto\x12\x15\x64ydxprotocol.revshare\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"4\n\x1bMarketMapperRevShareDetails\x12\x15\n\rexpiration_ts\x18\x01 \x01(\x04\"\xaf\x01\n\x1bUnconditionalRevShareConfig\x12Y\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32\x42.dydxprotocol.revshare.UnconditionalRevShareConfig.RecipientConfigB\x04\xc8\xde\x1f\x00\x1a\x35\n\x0fRecipientConfig\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x11\n\tshare_ppm\x18\x02 \x01(\r\"S\n\x13OrderRouterRevShare\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x11\n\tshare_ppm\x18\x02 \x01(\rB<Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.revshare.revshare_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/types'
  _globals['_UNCONDITIONALREVSHARECONFIG'].fields_by_name['configs']._loaded_options = None
  _globals['_UNCONDITIONALREVSHARECONFIG'].fields_by_name['configs']._serialized_options = b'\310\336\037\000'
  _globals['_ORDERROUTERREVSHARE'].fields_by_name['address']._loaded_options = None
  _globals['_ORDERROUTERREVSHARE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MARKETMAPPERREVSHAREDETAILS']._serialized_start=112
  _globals['_MARKETMAPPERREVSHAREDETAILS']._serialized_end=164
  _globals['_UNCONDITIONALREVSHARECONFIG']._serialized_start=167
  _globals['_UNCONDITIONALREVSHARECONFIG']._serialized_end=342
  _globals['_UNCONDITIONALREVSHARECONFIG_RECIPIENTCONFIG']._serialized_start=289
  _globals['_UNCONDITIONALREVSHARECONFIG_RECIPIENTCONFIG']._serialized_end=342
  _globals['_ORDERROUTERREVSHARE']._serialized_start=344
  _globals['_ORDERROUTERREVSHARE']._serialized_end=427
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.affiliates import affiliates_pb2 as _affiliates_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgRegisterAffiliate(_message.Message):
    __slots__ = ("referee", "affiliate")
    REFEREE_FIELD_NUMBER: _ClassVar[int]
    AFFILIATE_FIELD_NUMBER: _ClassVar[int]
    referee: str
    affiliate: str
    def __init__(self, referee: _Optional[str] = ..., affiliate: _Optional[str] = ...) -> None: ...

class MsgRegisterAffiliateResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateAffiliateTiers(_message.Message):
    __slots__ = ("authority", "tiers")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    TIERS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    tiers: _affiliates_pb2.AffiliateTiers
    def __init__(self, authority: _Optional[str] = ..., tiers: _Optional[_Union[_affiliates_pb2.AffiliateTiers, _Mapping]] = ...) -> None: ...

class MsgUpdateAffiliateTiersResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateAffiliateWhitelist(_message.Message):
    __slots__ = ("authority", "whitelist")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    WHITELIST_FIELD_NUMBER: _ClassVar[int]
    authority: str
    whitelist: _affiliates_pb2.AffiliateWhitelist
    def __init__(self, authority: _Optional[str] = ..., whitelist: _Optional[_Union[_affiliates_pb2.AffiliateWhitelist, _Mapping]] = ...) -> None: ...

class MsgUpdateAffiliateWhitelistResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/vault/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/vault/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2
from v4_proto.dydxprotocol.vault import params_pb2 as dydxprotocol_dot_vault_dot_params__pb2
from v4_proto.dydxprotocol.vault import share_pb2 as dydxprotocol_dot_vault_dot_share__pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as dydxprotocol_dot_vault_dot_vault__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x64ydxprotocol/vault/tx.proto\x12\x12\x64ydxprotocol.vault\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\x1a\x1f\x64ydxprotocol/vault/params.proto\x1a\x1e\x64ydxprotocol/vault/share.proto\x1a\x1e\x64ydxprotocol/vault/vault.proto\x1a\x14gogoproto/gogo.proto\"\xcc\x01\n\x15MsgDepositToMegavault\x12=\n\rsubaccount_id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountId\x12`\n\x0equote_quantums\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt:\x12\x82\xe7\xb0*\rsubaccount_id\"[\n\x1dMsgDepositToMegavaultResponse\x12:\n\rminted_shares\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\"\x8e\x02\n\x18MsgWithdrawFromMegavault\x12\x43\n\rsubaccount_id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12\x33\n\x06shares\x18\x02 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\x12\x64\n\x12min_quote_quantums\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt:\x12\x82\xe7\xb0*\rsubaccount_id\"\x84\x01\n MsgWithdrawFromMegavaultResponse\x12`\n\x0equote_quantums\x18\x01 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"\xa5\x01\n\x1dMsgUpdateDefaultQuotingParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12G\n\x16\x64\x65\x66\x61ult_quoting_params\x18\x02 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\'\n%MsgUpdateDefaultQuotingParamsResponse\"\xc2\x01\n\x11MsgSetVaultParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x08vault_id\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12;\n\x0cvault_params\x18\x03 \x01(\x0b\x32\x1f.dydxprotocol.vault.VaultParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1b\n\x19MsgSetVaultParamsResponse\"e\n\x0fMsgUnlockShares\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x15\n\rowner_address\x18\x02 \x01(\t:\x0e\x82\xe7\xb0*\tauthority\"W\n\x17MsgUnlockSharesResponse\x12<\n\x0funlocked_shares\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\"\x90\x01\n\x17MsgUpdateOperatorParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32\".dydxprotocol.vault.OperatorParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"!\n\x1fMsgUpdateOperatorParamsResponse\"\xe8\x01\n\x12MsgAllocateToVault\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x08vault_id\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12`\n\x0equote_quantums\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt:\x0e\x82\xe7\xb0*\tauthority\"\x1c\n\x1aMsgAllocateToVaultResponse\"\xea\x01\n\x14MsgRetrieveFromVault\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x08vault_id\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12`\n\x0equote_quantums\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt:\x0e\x82\xe7\xb0*\tauthority\"\x1e\n\x1cMsgRetrieveFromVaultResponse\"\x82\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x30\n\x06params\x18\x02 \x01(\x0b\x32\x1a.dydxprotocol.vault.ParamsB\x04\xc8\xde\x1f\x00:\x10\x18\x01\x82\xe7\xb0*\tauthority\"\xcf\x01\n\x18MsgSetVaultQuotingParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x08vault_id\x18\x02 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12?\n\x0equoting_params\x18\x03 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00:\x10\x18\x01\x82\xe7\xb0*\tauthority2\xa3\x07\n\x03Msg\x12r\n\x12\x44\x65positToMegavault\x12).dydxprotocol.vault.MsgDepositToMegavault\x1a\x31.dydxprotocol.vault.MsgDepositToMegavaultResponse\x12{\n\x15WithdrawFromMegavault\x12,.dydxprotocol.vault.MsgWithdrawFromMegavault\x1a\x34.dydxprotocol.vault.MsgWithdrawFromMegavaultResponse\x12\x8a\x01\n\x1aUpdateDefaultQuotingParams\x12\x31.dydxprotocol.vault.MsgUpdateDefaultQuotingParams\x1a\x39.dydxprotocol.vault.MsgUpdateDefaultQuotingParamsResponse\x12x\n\x14UpdateOperatorParams\x12+.dydxprotocol.vault.MsgUpdateOperatorParams\x1a\x33.dydxprotocol.vault.MsgUpdateOperatorParamsResponse\x12\x66\n\x0eSetVaultParams\x12%.dydxprotocol.vault.MsgSetVaultParams\x1a-.dydxprotocol.vault.MsgSetVaultParamsResponse\x12`\n\x0cUnlockShares\x12#.dydxprotocol.vault.MsgUnlockShares\x1a+.dydxprotocol.vault.MsgUnlockSharesResponse\x12i\n\x0f\x41llocateToVault\x12&.dydxprotocol.vault.MsgAllocateToVault\x1a..dydxprotocol.vault.MsgAllocateToVaultResponse\x12o\n\x11RetrieveFromVault\x12(.dydxprotocol.vault.MsgRetrieveFromVault\x1a\x30.dydxprotocol.vault.MsgRetrieveFromVaultResponseB9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_MSGDEPOSITTOMEGAVAULT'].fields_by_name['quote_quantums']._loaded_options = None
  _globals['_MSGDEPOSITTOMEGAVAULT'].fields_by_name['quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGDEPOSITTOMEGAVAULT']._loaded_options = None
  _globals['_MSGDEPOSITTOMEGAVAULT']._serialized_options = b'\202\347\260*\rsubaccount_id'
  _globals['_MSGDEPOSITTOMEGAVAULTRESPONSE'].fields_by_name['minted_shares']._loaded_options = None
  _globals['_MSGDEPOSITTOMEGAVAULTRESPONSE'].fields_by_name['minted_shares']._serialized_options = b'\310\336\037\000'
  _globals['_MSGWITHDRAWFROMMEGAVAULT'].fields_by_name['subaccount_id']._loaded_options = None
  _globals['_MSGWITHDRAWFROMMEGAVAULT'].fields_by_name['subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGWITHDRAWFROMMEGAVAULT'].fields_by_name['shares']._loaded_options = None
  _globals['_MSGWITHDRAWFROMMEGAVAULT'].fields_by_name['shares']._serialized_options = b'\310\336\037\000'
  _globals['_MSGWITHDRAWFROMMEGAVAULT'].fields_by_name['min_quote_quantums']._loaded_options = None
  _globals['_MSGWITHDRAWFROMMEGAVAULT'].fields_by_name['min_quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGWITHDRAWFROMMEGAVAULT']._loaded_options = None
  _globals['_MSGWITHDRAWFROMMEGAVAULT']._serialized_options = b'\202\347\260*\rsubaccount_id'
  _globals['_MSGWITHDRAWFROMMEGAVAULTRESPONSE'].fields_by_name['quote_quantums']._loaded_options = None
  _globals['_MSGWITHDRAWFROMMEGAVAULTRESPONSE'].fields_by_name['quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['default_quoting_params']._loaded_options = None
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS'].fields_by_name['default_quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._loaded_options = None
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSETVAULTPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETVAULTPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETVAULTPARAMS'].fields_by_name['vault_id']._loaded_options = None
  _globals['_MSGSETVAULTPARAMS'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVAULTPARAMS'].fields_by_name['vault_params']._loaded_options = None
  _globals['_MSGSETVAULTPARAMS'].fields_by_name['vault_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVAULTPARAMS']._loaded_options = None
  _globals['_MSGSETVAULTPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUNLOCKSHARES'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUNLOCKSHARES'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUNLOCKSHARES']._loaded_options = None
  _globals['_MSGUNLOCKSHARES']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUNLOCKSHARESRESPONSE'].fields_by_name['unlocked_shares']._loaded_options = None
  _globals['_MSGUNLOCKSHARESRESPONSE'].fields_by_name['unlocked_shares']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEOPERATORPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEOPERATORPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEOPERATORPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEOPERATORPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEOPERATORPARAMS']._loaded_options = None
  _globals['_MSGUPDATEOPERATORPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGALLOCATETOVAULT'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGALLOCATETOVAULT'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGALLOCATETOVAULT'].fields_by_name['vault_id']._loaded_options = None
  _globals['_MSGALLOCATETOVAULT'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGALLOCATETOVAULT'].fields_by_name['quote_quantums']._loaded_options = None
  _globals['_MSGALLOCATETOVAULT'].fields_by_name['quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGALLOCATETOVAULT']._loaded_options = None
  _globals['_MSGALLOCATETOVAULT']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGRETRIEVEFROMVAULT'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGRETRIEVEFROMVAULT'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGRETRIEVEFROMVAULT'].fields_by_name['vault_id']._loaded_options = None
  _globals['_MSGRETRIEVEFROMVAULT'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGRETRIEVEFROMVAULT'].fields_by_name['quote_quantums']._loaded_options = None
  _globals['_MSGRETRIEVEFROMVAULT'].fields_by_name['quote_quantums']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGRETRIEVEFROMVAULT']._loaded_options = None
  _globals['_MSGRETRIEVEFROMVAULT']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\030\001\202\347\260*\tauthority'
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['vault_id']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['quoting_params']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS'].fields_by_name['quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETVAULTQUOTINGPARAMS']._loaded_options = None
  _globals['_MSGSETVAULTQUOTINGPARAMS']._serialized_options = b'\030\001\202\347\260*\tauthority'
  _globals['_MSGDEPOSITTOMEGAVAULT']._serialized_start=266
  _globals['_MSGDEPOSITTOMEGAVAULT']._serialized_end=470
  _globals['_MSGDEPOSITTOMEGAVAULTRESPONSE']._serialized_start=472
  _globals['_MSGDEPOSITTOMEGAVAULTRESPONSE']._serialized_end=563
  _globals['_MSGWITHDRAWFROMMEGAVAULT']._serialized_start=566
  _globals['_MSGWITHDRAWFROMMEGAVAULT']._serialized_end=836
  _globals['_MSGWITHDRAWFROMMEGAVAULTRESPONSE']._serialized_start=839
  _globals['_MSGWITHDRAWFROMMEGAVAULTRESPONSE']._serialized_end=971
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._serialized_start=974
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMS']._serialized_end=1139
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMSRESPONSE']._serialized_start=1141
  _globals['_MSGUPDATEDEFAULTQUOTINGPARAMSRESPONSE']._serialized_end=1180
  _globals['_MSGSETVAULTPARAMS']._serialized_start=1183
  _globals['_MSGSETVAULTPARAMS']._serialized_end=1377
  _globals['_MSGSETVAULTPARAMSRESPONSE']._serialized_start=1379
  _globals['_MSGSETVAULTPARAMSRESPONSE']._serialized_end=1406
  _globals['_MSGUNLOCKSHARES']._serialized_start=1408
  _globals['_MSGUNLOCKSHARES']._serialized_end=1509
  _globals['_MSGUNLOCKSHARESRESPONSE']._serialized_start=1511
  _globals['_MSGUNLOCKSHARESRESPONSE']._serialized_end=1598
  _globals['_MSGUPDATEOPERATORPARAMS']._serialized_start=1601
  _globals['_MSGUPDATEOPERATORPARAMS']._serialized_end=1745
  _globals['_MSGUPDATEOPERATORPARAMSRESPONSE']._serialized_start=1747
  _globals['_MSGUPDATEOPERATORPARAMSRESPONSE']._serialized_end=1780
  _globals['_MSGALLOCATETOVAULT']._serialized_start=1783
  _globals['_MSGALLOCATETOVAULT']._serialized_end=2015
  _globals['_MSGALLOCATETOVAULTRESPONSE']._serialized_start=2017
  _globals['_MSGALLOCATETOVAULTRESPONSE']._serialized_end=2045
  _globals['_MSGRETRIEVEFROMVAULT']._serialized_start=2048
  _globals['_MSGRETRIEVEFROMVAULT']._serialized_end=2282
  _globals['_MSGRETRIEVEFROMVAULTRESPONSE']._serialized_start=2284
  _globals['_MSGRETRIEVEFROMVAULTRESPONSE']._serialized_end=2314
  _globals['_MSGUPDATEPARAMS']._serialized_start=2317
  _globals['_MSGUPDATEPARAMS']._serialized_end=2447
  _globals['_MSGSETVAULTQUOTINGPARAMS']._serialized_start=2450
  _globals['_MSGSETVAULTQUOTINGPARAMS']._serialized_end=2657
  _globals['_MSG']._serialized_start=2660
  _globals['_MSG']._serialized_end=3591
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tendermint/types/types.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'tendermint/types/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from v4_proto.tendermint.crypto import proof_pb2 as tendermint_dot_crypto_dot_proof__pb2
from v4_proto.tendermint.version import types_pb2 as tendermint_dot_version_dot_types__pb2
from v4_proto.tendermint.types import validator_pb2 as tendermint_dot_types_dot_validator__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctendermint/types/types.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dtendermint/crypto/proof.proto\x1a\x1etendermint/version/types.proto\x1a tendermint/types/validator.proto\",\n\rPartSetHeader\x12\r\n\x05total\x18\x01 \x01(\r\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\"S\n\x04Part\x12\r\n\x05index\x18\x01 \x01(\r\x12\r\n\x05\x62ytes\x18\x02 \x01(\x0c\x12-\n\x05proof\x18\x03 \x01(\x0b\x32\x18.tendermint.crypto.ProofB\x04\xc8\xde\x1f\x00\"W\n\x07\x42lockID\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12>\n\x0fpart_set_header\x18\x02 \x01(\x0b\x32\x1f.tendermint.types.PartSetHeaderB\x04\xc8\xde\x1f\x00\"\xb3\x03\n\x06Header\x12\x34\n\x07version\x18\x01 \x01(\x0b\x32\x1d.tendermint.version.ConsensusB\x04\xc8\xde\x1f\x00\x12\x1d\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x32\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x36\n\rlast_block_id\x18\x05 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\x04\xc8\xde\x1f\x00\x12\x18\n\x10last_commit_hash\x18\x06 \x01(\x0c\x12\x11\n\tdata_hash\x18\x07 \x01(\x0c\x12\x17\n\x0fvalidators_hash\x18\x08 \x01(\x0c\x12\x1c\n\x14next_validators_hash\x18\t \x01(\x0c\x12\x16\n\x0e\x63onsensus_hash\x18\n \x01(\x0c\x12\x10\n\x08\x61pp_hash\x18\x0b \x01(\x0c\x12\x19\n\x11last_results_hash\x18\x0c \x01(\x0c\x12\x15\n\revidence_hash\x18\r \x01(\x0c\x12\x18\n\x10proposer_address\x18\x0e \x01(\x0c\"\x13\n\x04\x44\x61ta\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\"\xc2\x02\n\x04Vote\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.tendermint.types.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x05\x12<\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\x12\x37\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x19\n\x11validator_address\x18\x06 \x01(\x0c\x12\x17\n\x0fvalidator_index\x18\x07 \x01(\x05\x12\x11\n\tsignature\x18\x08 \x01(\x0c\x12\x11\n\textension\x18\t \x01(\x0c\x12\x1b\n\x13\x65xtension_signature\x18\n \x01(\x0c\"\x9c\x01\n\x06\x43ommit\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12<\n\x08\x62lock_id\x18\x03 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\x12\x35\n\nsignatures\x18\x04 \x03(\x0b\x32\x1b.tendermint.types.CommitSigB\x04\xc8\xde\x1f\x00\"\xa8\x01\n\tCommitSig\x12\x34\n\rblock_id_flag\x18\x01 \x01(\x0e\x32\x1d.tendermint.types.BlockIDFlag\x12\x19\n\x11validator_address\x18\x02 \x01(\x0c\x12\x37\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x11\n\tsignature\x18\x04 \x01(\x0c\"\xb5\x01\n\x0e\x45xtendedCommit\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12<\n\x08\x62lock_id\x18\x03 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\x12\x46\n\x13\x65xtended_signatures\x18\x04 \x03(\x0b\x32#.tendermint.types.ExtendedCommitSigB\x04\xc8\xde\x1f\x00\"\xe0\x01\n\x11\x45xtendedCommitSig\x12\x34\n\rblock_id_flag\x18\x01 \x01(\x0e\x32\x1d.tendermint.types.BlockIDFlag\x12\x19\n\x11validator_address\x18\x02 \x01(\x0c\x12\x37\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x11\n\tsignature\x18\x04 \x01(\x0c\x12\x11\n\textension\x18\x05 \x01(\x0c\x12\x1b\n\x13\x65xtension_signature\x18\x06 \x01(\x0c\"\xf5\x01\n\x08Proposal\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.tendermint.types.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x05\x12\x11\n\tpol_round\x18\x04 \x01(\x05\x12<\n\x08\x62lock_id\x18\x05 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\x12\x37\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x11\n\tsignature\x18\x07 \x01(\x0c\"b\n\x0cSignedHeader\x12(\n\x06header\x18\x01 \x01(\x0b\x32\x18.tendermint.types.Header\x12(\n\x06\x63ommit\x18\x02 \x01(\x0b\x32\x18.tendermint.types.Commit\"z\n\nLightBlock\x12\x35\n\rsigned_header\x18\x01 \x01(\x0b\x32\x1e.tendermint.types.SignedHeader\x12\x35\n\rvalidator_set\x18\x02 \x01(\x0b\x32\x1e.tendermint.types.ValidatorSet\"\x9e\x01\n\tBlockMeta\x12<\n\x08\x62lock_id\x18\x01 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockID\x12\x12\n\nblock_size\x18\x02 \x01(\x03\x12.\n\x06header\x18\x03 \x01(\x0b\x32\x18.tendermint.types.HeaderB\x04\xc8\xde\x1f\x00\x12\x0f\n\x07num_txs\x18\x04 \x01(\x03\"S\n\x07TxProof\x12\x11\n\troot_hash\x18\x01 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\'\n\x05proof\x18\x03 \x01(\x0b\x32\x18.tendermint.crypto.Proof*\xd7\x01\n\rSignedMsgType\x12,\n\x17SIGNED_MSG_TYPE_UNKNOWN\x10\x00\x1a\x0f\x8a\x9d \x0bUnknownType\x12,\n\x17SIGNED_MSG_TYPE_PREVOTE\x10\x01\x1a\x0f\x8a\x9d \x0bPrevoteType\x12\x30\n\x19SIGNED_MSG_TYPE_PRECOMMIT\x10\x02\x1a\x11\x8a\x9d \rPrecommitType\x12.\n\x18SIGNED_MSG_TYPE_PROPOSAL\x10 \x1a\x10\x8a\x9d \x0cProposalType\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x01\x42\x35Z3github.com/cometbft/cometbft/proto/tendermint/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/cometbft/cometbft/proto/tendermint/types'
  _globals['_SIGNEDMSGTYPE']._loaded_options = None
  _globals['_SIGNEDMSGTYPE']._serialized_options = b'\210\243\036\000\250\244\036\001'
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_UNKNOWN"]._loaded_options = None
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_UNKNOWN"]._serialized_options = b'\212\235 \013UnknownType'
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PREVOTE"]._loaded_options = None
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PREVOTE"]._serialized_options = b'\212\235 \013PrevoteType'
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PRECOMMIT"]._loaded_options = None
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PRECOMMIT"]._serialized_options = b'\212\235 \rPrecommitType'
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PROPOSAL"]._loaded_options = None
  _globals['_SIGNEDMSGTYPE'].values_by_name["SIGNED_MSG_TYPE_PROPOSAL"]._serialized_options = b'\212\235 \014ProposalType'
  _globals['_PART'].fields_by_name['proof']._loaded_options = None
  _globals['_PART'].fields_by_name['proof']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKID'].fields_by_name['part_set_header']._loaded_options = None
  _globals['_BLOCKID'].fields_by_name['part_set_header']._serialized_options = b'\310\336\037\000'
  _globals['_HEADER'].fields_by_name['version']._loaded_options = None
  _globals['_HEADER'].fields_by_name['version']._serialized_options = b'\310\336\037\000'
  _globals['_HEADER'].fields_by_name['chain_id']._loaded_options = None
  _globals['_HEADER'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_HEADER'].fields_by_name['time']._loaded_options = None
  _globals['_HEADER'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_HEADER'].fields_by_name['last_block_id']._loaded_options = None
  _globals['_HEADER'].fields_by_name['last_block_id']._serialized_options = b'\310\336\037\000'
  _globals['_VOTE'].fields_by_name['block_id']._loaded_options = None
  _globals['_VOTE'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_VOTE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_VOTE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_COMMIT'].fields_by_name['block_id']._loaded_options = None
  _globals['_COMMIT'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_COMMIT'].fields_by_name['signatures']._loaded_options = None
  _globals['_COMMIT'].fields_by_name['signatures']._serialized_options = b'\310\336\037\000'
  _globals['_COMMITSIG'].fields_by_name['timestamp']._loaded_options = None
  _globals['_COMMITSIG'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EXTENDEDCOMMIT'].fields_by_name['block_id']._loaded_options = None
  _globals['_EXTENDEDCOMMIT'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_EXTENDEDCOMMIT'].fields_by_name['extended_signatures']._loaded_options = None
  _globals['_EXTENDEDCOMMIT'].fields_by_name['extended_signatures']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDCOMMITSIG'].fields_by_name['timestamp']._loaded_options = None
  _globals['_EXTENDEDCOMMITSIG'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_PROPOSAL'].fields_by_name['block_id']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_PROPOSAL'].fields_by_name['timestamp']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_BLOCKMETA'].fields_by_name['block_id']._loaded_options = None
  _globals['_BLOCKMETA'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_BLOCKMETA'].fields_by_name['header']._loaded_options = None
  _globals['_BLOCKMETA'].fields_by_name['header']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDMSGTYPE']._serialized_start=2666
  _globals['_SIGNEDMSGTYPE']._serialized_end=2881
  _globals['_PARTSETHEADER']._serialized_start=202
  _globals['_PARTSETHEADER']._serialized_end=246
  _globals['_PART']._serialized_start=248
  _globals['_PART']._serialized_end=331
  _globals['_BLOCKID']._serialized_start=333
  _globals['_BLOCKID']._serialized_end=420
  _globals['_HEADER']._serialized_start=423
  _globals['_HEADER']._serialized_end=858
  _globals['_DATA']._serialized_start=860
  _globals['_DATA']._serialized_end=879
  _globals['_VOTE']._serialized_start=882
  _globals['_VOTE']._serialized_end=1204
  _globals['_COMMIT']._serialized_start=1207
  _globals['_COMMIT']._serialized_end=1363
  _globals['_COMMITSIG']._serialized_start=1366
  _globals['_COMMITSIG']._serialized_end=1534
  _globals['_EXTENDEDCOMMIT']._serialized_start=1537
  _globals['_EXTENDEDCOMMIT']._serialized_end=1718
  _globals['_EXTENDEDCOMMITSIG']._serialized_start=1721
  _globals['_EXTENDEDCOMMITSIG']._serialized_end=1945
  _globals['_PROPOSAL']._serialized_start=1948
  _globals['_PROPOSAL']._serialized_end=2193
  _globals['_SIGNEDHEADER']._serialized_start=2195
  _globals['_SIGNEDHEADER']._serialized_end=2293
  _globals['_LIGHTBLOCK']._serialized_start=2295
  _globals['_LIGHTBLOCK']._serialized_end=2417
  _globals['_BLOCKMETA']._serialized_start=2420
  _globals['_BLOCKMETA']._serialized_end=2578
  _globals['_TXPROOF']._serialized_start=2580
  _globals['_TXPROOF']._serialized_end=2663
# @@protoc_insertion_point(module_scope)



import datetime

from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from v4_proto.tendermint.types import types_pb2 as _types_pb2
from v4_proto.tendermint.types import validator_pb2 as _validator_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Evidence(_message.Message):
    __slots__ = ("duplicate_vote_evidence", "light_client_attack_evidence")
    DUPLICATE_VOTE_EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    LIGHT_CLIENT_ATTACK_EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    duplicate_vote_evidence: DuplicateVoteEvidence
    light_client_attack_evidence: LightClientAttackEvidence
    def __init__(self, duplicate_vote_evidence: _Optional[_Union[DuplicateVoteEvidence, _Mapping]] = ..., light_client_attack_evidence: _Optional[_Union[LightClientAttackEvidence, _Mapping]] = ...) -> None: ...

class DuplicateVoteEvidence(_message.Message):
    __slots__ = ("vote_a", "vote_b", "total_voting_power", "validator_power", "timestamp")
    VOTE_A_FIELD_NUMBER: _ClassVar[int]
    VOTE_B_FIELD_NUMBER: _ClassVar[int]
    TOTAL_VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_POWER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    vote_a: _types_pb2.Vote
    vote_b: _types_pb2.Vote
    total_voting_power: int
    validator_power: int
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, vote_a: _Optional[_Union[_types_pb2.Vote, _Mapping]] = ..., vote_b: _Optional[_Union[_types_pb2.Vote, _Mapping]] = ..., total_voting_power: _Optional[int] = ..., validator_power: _Optional[int] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class LightClientAttackEvidence(_message.Message):
    __slots__ = ("conflicting_block", "common_height", "byzantine_validators", "total_voting_power", "timestamp")
    CONFLICTING_BLOCK_FIELD_NUMBER: _ClassVar[int]
    COMMON_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    BYZANTINE_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    conflicting_block: _types_pb2.LightBlock
    common_height: int
    byzantine_validators: _containers.RepeatedCompositeFieldContainer[_validator_pb2.Validator]
    total_voting_power: int
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, conflicting_block: _Optional[_Union[_types_pb2.LightBlock, _Mapping]] = ..., common_height: _Optional[int] = ..., byzantine_validators: _Optional[_Iterable[_Union[_validator_pb2.Validator, _Mapping]]] = ..., total_voting_power: _Optional[int] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class EvidenceList(_message.Message):
    __slots__ = ("evidence",)
    EVIDENCE_FIELD_NUMBER: _ClassVar[int]
    evidence: _containers.RepeatedCompositeFieldContainer[Evidence]
    def __init__(self, evidence: _Optional[_Iterable[_Union[Evidence, _Mapping]]] = ...) -> None: ...



import datetime

from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DowntimeParams(_message.Message):
    __slots__ = ("durations",)
    DURATIONS_FIELD_NUMBER: _ClassVar[int]
    durations: _containers.RepeatedCompositeFieldContainer[_duration_pb2.Duration]
    def __init__(self, durations: _Optional[_Iterable[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]]] = ...) -> None: ...

class SynchronyParams(_message.Message):
    __slots__ = ("next_block_delay",)
    NEXT_BLOCK_DELAY_FIELD_NUMBER: _ClassVar[int]
    next_block_delay: _duration_pb2.Duration
    def __init__(self, next_block_delay: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/crisis/v1beta1/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/crisis/v1beta1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/crisis/v1beta1/tx.proto\x12\x15\x63osmos.crisis.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xad\x01\n\x12MsgVerifyInvariant\x12(\n\x06sender\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x1d\n\x15invariant_module_name\x18\x02 \x01(\t\x12\x17\n\x0finvariant_route\x18\x03 \x01(\t:5\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1d\x63osmos-sdk/MsgVerifyInvariant\"\x1c\n\x1aMsgVerifyInvariantResponse\"\xb2\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\x0c\x63onstant_fee\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:6\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*#cosmos-sdk/x/crisis/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2\xe5\x01\n\x03Msg\x12o\n\x0fVerifyInvariant\x12).cosmos.crisis.v1beta1.MsgVerifyInvariant\x1a\x31.cosmos.crisis.v1beta1.MsgVerifyInvariantResponse\x12\x66\n\x0cUpdateParams\x12&.cosmos.crisis.v1beta1.MsgUpdateParams\x1a..cosmos.crisis.v1beta1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42-Z+github.com/cosmos/cosmos-sdk/x/crisis/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crisis.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/x/crisis/types'
  _globals['_MSGVERIFYINVARIANT'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGVERIFYINVARIANT'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGVERIFYINVARIANT']._loaded_options = None
  _globals['_MSGVERIFYINVARIANT']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\035cosmos-sdk/MsgVerifyInvariant'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['constant_fee']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['constant_fee']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*#cosmos-sdk/x/crisis/MsgUpdateParams'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGVERIFYINVARIANT']._serialized_start=183
  _globals['_MSGVERIFYINVARIANT']._serialized_end=356
  _globals['_MSGVERIFYINVARIANTRESPONSE']._serialized_start=358
  _globals['_MSGVERIFYINVARIANTRESPONSE']._serialized_end=386
  _globals['_MSGUPDATEPARAMS']._serialized_start=389
  _globals['_MSGUPDATEPARAMS']._serialized_end=567
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=569
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=594
  _globals['_MSG']._serialized_start=597
  _globals['_MSG']._serialized_end=826
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/accountplus/genesis.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/accountplus/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.accountplus import accountplus_pb2 as dydxprotocol_dot_accountplus_dot_accountplus__pb2
from v4_proto.dydxprotocol.accountplus import models_pb2 as dydxprotocol_dot_accountplus_dot_models__pb2
from v4_proto.dydxprotocol.accountplus import params_pb2 as dydxprotocol_dot_accountplus_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&dydxprotocol/accountplus/genesis.proto\x12\x18\x64ydxprotocol.accountplus\x1a\x14gogoproto/gogo.proto\x1a*dydxprotocol/accountplus/accountplus.proto\x1a%dydxprotocol/accountplus/models.proto\x1a%dydxprotocol/accountplus/params.proto\"r\n\x11\x41uthenticatorData\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12L\n\x0e\x61uthenticators\x18\x02 \x03(\x0b\x32..dydxprotocol.accountplus.AccountAuthenticatorB\x04\xc8\xde\x1f\x00\"\xf4\x01\n\x0cGenesisState\x12>\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32&.dydxprotocol.accountplus.AccountStateB\x04\xc8\xde\x1f\x00\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32 .dydxprotocol.accountplus.ParamsB\x04\xc8\xde\x1f\x00\x12\x1d\n\x15next_authenticator_id\x18\x03 \x01(\x04\x12M\n\x12\x61uthenticator_data\x18\x04 \x03(\x0b\x32+.dydxprotocol.accountplus.AuthenticatorDataB\x04\xc8\xde\x1f\x00\x42?Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.accountplus.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/accountplus/types'
  _globals['_AUTHENTICATORDATA'].fields_by_name['authenticators']._loaded_options = None
  _globals['_AUTHENTICATORDATA'].fields_by_name['authenticators']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['accounts']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['accounts']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['authenticator_data']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['authenticator_data']._serialized_options = b'\310\336\037\000'
  _globals['_AUTHENTICATORDATA']._serialized_start=212
  _globals['_AUTHENTICATORDATA']._serialized_end=326
  _globals['_GENESISSTATE']._serialized_start=329
  _globals['_GENESISSTATE']._serialized_end=573
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IndexerTendermintEventWrapper(_message.Message):
    __slots__ = ("event", "txn_hash")
    EVENT_FIELD_NUMBER: _ClassVar[int]
    TXN_HASH_FIELD_NUMBER: _ClassVar[int]
    event: IndexerTendermintEvent
    txn_hash: str
    def __init__(self, event: _Optional[_Union[IndexerTendermintEvent, _Mapping]] = ..., txn_hash: _Optional[str] = ...) -> None: ...

class IndexerEventsStoreValue(_message.Message):
    __slots__ = ("events",)
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedCompositeFieldContainer[IndexerTendermintEventWrapper]
    def __init__(self, events: _Optional[_Iterable[_Union[IndexerTendermintEventWrapper, _Mapping]]] = ...) -> None: ...

class IndexerTendermintEvent(_message.Message):
    __slots__ = ("subtype", "transaction_index", "block_event", "event_index", "version", "data_bytes")
    class BlockEvent(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        BLOCK_EVENT_UNSPECIFIED: _ClassVar[IndexerTendermintEvent.BlockEvent]
        BLOCK_EVENT_BEGIN_BLOCK: _ClassVar[IndexerTendermintEvent.BlockEvent]
        BLOCK_EVENT_END_BLOCK: _ClassVar[IndexerTendermintEvent.BlockEvent]
    BLOCK_EVENT_UNSPECIFIED: IndexerTendermintEvent.BlockEvent
    BLOCK_EVENT_BEGIN_BLOCK: IndexerTendermintEvent.BlockEvent
    BLOCK_EVENT_END_BLOCK: IndexerTendermintEvent.BlockEvent
    SUBTYPE_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_INDEX_FIELD_NUMBER: _ClassVar[int]
    BLOCK_EVENT_FIELD_NUMBER: _ClassVar[int]
    EVENT_INDEX_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    DATA_BYTES_FIELD_NUMBER: _ClassVar[int]
    subtype: str
    transaction_index: int
    block_event: IndexerTendermintEvent.BlockEvent
    event_index: int
    version: int
    data_bytes: bytes
    def __init__(self, subtype: _Optional[str] = ..., transaction_index: _Optional[int] = ..., block_event: _Optional[_Union[IndexerTendermintEvent.BlockEvent, str]] = ..., event_index: _Optional[int] = ..., version: _Optional[int] = ..., data_bytes: _Optional[bytes] = ...) -> None: ...

class IndexerTendermintBlock(_message.Message):
    __slots__ = ("height", "time", "events", "tx_hashes")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    TX_HASHES_FIELD_NUMBER: _ClassVar[int]
    height: int
    time: _timestamp_pb2.Timestamp
    events: _containers.RepeatedCompositeFieldContainer[IndexerTendermintEvent]
    tx_hashes: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, height: _Optional[int] = ..., time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., events: _Optional[_Iterable[_Union[IndexerTendermintEvent, _Mapping]]] = ..., tx_hashes: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/bank/v1beta1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/bank/v1beta1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from v4_proto.cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.query.v1 import query_pb2 as cosmos_dot_query_dot_v1_dot_query__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/bank/v1beta1/query.proto\x12\x13\x63osmos.bank.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1b\x63osmos/query/v1/query.proto\x1a\x11\x61mino/amino.proto\"Y\n\x13QueryBalanceRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"B\n\x14QueryBalanceResponse\x12*\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.Coin\"\xa1\x01\n\x17QueryAllBalancesRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x12\x15\n\rresolve_denom\x18\x03 \x01(\x08:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xcc\x01\n\x18QueryAllBalancesResponse\x12s\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x90\x01\n\x1dQuerySpendableBalancesRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xd2\x01\n\x1eQuerySpendableBalancesResponse\x12s\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"i\n#QuerySpendableBalanceByDenomRequest\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"R\n$QuerySpendableBalanceByDenomResponse\x12*\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.Coin\"_\n\x17QueryTotalSupplyRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xca\x01\n\x18QueryTotalSupplyResponse\x12q\n\x06supply\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"%\n\x14QuerySupplyOfRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"M\n\x15QuerySupplyOfResponse\x12\x34\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x14\n\x12QueryParamsRequest\"M\n\x13QueryParamsResponse\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32\x1b.cosmos.bank.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"X\n\x1aQueryDenomsMetadataRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x97\x01\n\x1bQueryDenomsMetadataResponse\x12;\n\tmetadatas\x18\x01 \x03(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"*\n\x19QueryDenomMetadataRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"X\n\x1aQueryDenomMetadataResponse\x12:\n\x08metadata\x18\x01 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"7\n&QueryDenomMetadataByQueryStringRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"e\n\'QueryDenomMetadataByQueryStringResponse\x12:\n\x08metadata\x18\x01 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"d\n\x17QueryDenomOwnersRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"n\n\nDenomOwner\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x35\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x8e\x01\n\x18QueryDenomOwnersResponse\x12\x35\n\x0c\x64\x65nom_owners\x18\x01 \x03(\x0b\x32\x1f.cosmos.bank.v1beta1.DenomOwner\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"e\n\x17QuerySendEnabledRequest\x12\x0e\n\x06\x64\x65noms\x18\x01 \x03(\t\x12:\n\npagination\x18\x63 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8f\x01\n\x18QuerySendEnabledResponse\x12\x36\n\x0csend_enabled\x18\x01 \x03(\x0b\x32 .cosmos.bank.v1beta1.SendEnabled\x12;\n\npagination\x18\x63 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\x8f\x10\n\x05Query\x12\x9d\x01\n\x07\x42\x61lance\x12(.cosmos.bank.v1beta1.QueryBalanceRequest\x1a).cosmos.bank.v1beta1.QueryBalanceResponse\"=\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/bank/v1beta1/balances/{address}/by_denom\x12\xa0\x01\n\x0b\x41llBalances\x12,.cosmos.bank.v1beta1.QueryAllBalancesRequest\x1a-.cosmos.bank.v1beta1.QueryAllBalancesResponse\"4\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02)\x12\'/cosmos/bank/v1beta1/balances/{address}\x12\xbc\x01\n\x11SpendableBalances\x12\x32.cosmos.bank.v1beta1.QuerySpendableBalancesRequest\x1a\x33.cosmos.bank.v1beta1.QuerySpendableBalancesResponse\">\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x33\x12\x31/cosmos/bank/v1beta1/spendable_balances/{address}\x12\xd7\x01\n\x17SpendableBalanceByDenom\x12\x38.cosmos.bank.v1beta1.QuerySpendableBalanceByDenomRequest\x1a\x39.cosmos.bank.v1beta1.QuerySpendableBalanceByDenomResponse\"G\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02<\x12:/cosmos/bank/v1beta1/spendable_balances/{address}/by_denom\x12\x94\x01\n\x0bTotalSupply\x12,.cosmos.bank.v1beta1.QueryTotalSupplyRequest\x1a-.cosmos.bank.v1beta1.QueryTotalSupplyResponse\"(\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/bank/v1beta1/supply\x12\x94\x01\n\x08SupplyOf\x12).cosmos.bank.v1beta1.QuerySupplyOfRequest\x1a*.cosmos.bank.v1beta1.QuerySupplyOfResponse\"1\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02&\x12$/cosmos/bank/v1beta1/supply/by_denom\x12\x85\x01\n\x06Params\x12\'.cosmos.bank.v1beta1.QueryParamsRequest\x1a(.cosmos.bank.v1beta1.QueryParamsResponse\"(\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/bank/v1beta1/params\x12\xab\x01\n\rDenomMetadata\x12..cosmos.bank.v1beta1.QueryDenomMetadataRequest\x1a/.cosmos.bank.v1beta1.QueryDenomMetadataResponse\"9\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02.\x12,/cosmos/bank/v1beta1/denoms_metadata/{denom}\x12\xda\x01\n\x1a\x44\x65nomMetadataByQueryString\x12;.cosmos.bank.v1beta1.QueryDenomMetadataByQueryStringRequest\x1a<.cosmos.bank.v1beta1.QueryDenomMetadataByQueryStringResponse\"A\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/bank/v1beta1/denoms_metadata_by_query_string\x12\xa6\x01\n\x0e\x44\x65nomsMetadata\x12/.cosmos.bank.v1beta1.QueryDenomsMetadataRequest\x1a\x30.cosmos.bank.v1beta1.QueryDenomsMetadataResponse\"1\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02&\x12$/cosmos/bank/v1beta1/denoms_metadata\x12\xa2\x01\n\x0b\x44\x65nomOwners\x12,.cosmos.bank.v1beta1.QueryDenomOwnersRequest\x1a-.cosmos.bank.v1beta1.QueryDenomOwnersResponse\"6\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02+\x12)/cosmos/bank/v1beta1/denom_owners/{denom}\x12\x9a\x01\n\x0bSendEnabled\x12,.cosmos.bank.v1beta1.QuerySendEnabledRequest\x1a-.cosmos.bank.v1beta1.QuerySendEnabledResponse\".\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02#\x12!/cosmos/bank/v1beta1/send_enabledB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _globals['_QUERYBALANCEREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYBALANCEREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYBALANCEREQUEST']._loaded_options = None
  _globals['_QUERYBALANCEREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYALLBALANCESREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYALLBALANCESREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYALLBALANCESREQUEST']._loaded_options = None
  _globals['_QUERYALLBALANCESREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYALLBALANCESRESPONSE'].fields_by_name['balances']._loaded_options = None
  _globals['_QUERYALLBALANCESRESPONSE'].fields_by_name['balances']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_QUERYSPENDABLEBALANCESREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYSPENDABLEBALANCESREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYSPENDABLEBALANCESREQUEST']._loaded_options = None
  _globals['_QUERYSPENDABLEBALANCESREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYSPENDABLEBALANCESRESPONSE'].fields_by_name['balances']._loaded_options = None
  _globals['_QUERYSPENDABLEBALANCESRESPONSE'].fields_by_name['balances']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_QUERYSPENDABLEBALANCEBYDENOMREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_QUERYSPENDABLEBALANCEBYDENOMREQUEST'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYSPENDABLEBALANCEBYDENOMREQUEST']._loaded_options = None
  _globals['_QUERYSPENDABLEBALANCEBYDENOMREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYTOTALSUPPLYREQUEST']._loaded_options = None
  _globals['_QUERYTOTALSUPPLYREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYTOTALSUPPLYRESPONSE'].fields_by_name['supply']._loaded_options = None
  _globals['_QUERYTOTALSUPPLYRESPONSE'].fields_by_name['supply']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_QUERYSUPPLYOFRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_QUERYSUPPLYOFRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDENOMSMETADATARESPONSE'].fields_by_name['metadatas']._loaded_options = None
  _globals['_QUERYDENOMSMETADATARESPONSE'].fields_by_name['metadatas']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDENOMMETADATARESPONSE'].fields_by_name['metadata']._loaded_options = None
  _globals['_QUERYDENOMMETADATARESPONSE'].fields_by_name['metadata']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDENOMMETADATABYQUERYSTRINGRESPONSE'].fields_by_name['metadata']._loaded_options = None
  _globals['_QUERYDENOMMETADATABYQUERYSTRINGRESPONSE'].fields_by_name['metadata']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_DENOMOWNER'].fields_by_name['address']._loaded_options = None
  _globals['_DENOMOWNER'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DENOMOWNER'].fields_by_name['balance']._loaded_options = None
  _globals['_DENOMOWNER'].fields_by_name['balance']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Balance']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Balance']._serialized_options = b'\210\347\260*\001\202\323\344\223\0022\0220/cosmos/bank/v1beta1/balances/{address}/by_denom'
  _globals['_QUERY'].methods_by_name['AllBalances']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllBalances']._serialized_options = b'\210\347\260*\001\202\323\344\223\002)\022\'/cosmos/bank/v1beta1/balances/{address}'
  _globals['_QUERY'].methods_by_name['SpendableBalances']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SpendableBalances']._serialized_options = b'\210\347\260*\001\202\323\344\223\0023\0221/cosmos/bank/v1beta1/spendable_balances/{address}'
  _globals['_QUERY'].methods_by_name['SpendableBalanceByDenom']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SpendableBalanceByDenom']._serialized_options = b'\210\347\260*\001\202\323\344\223\002<\022:/cosmos/bank/v1beta1/spendable_balances/{address}/by_denom'
  _globals['_QUERY'].methods_by_name['TotalSupply']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TotalSupply']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\035\022\033/cosmos/bank/v1beta1/supply'
  _globals['_QUERY'].methods_by_name['SupplyOf']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SupplyOf']._serialized_options = b'\210\347\260*\001\202\323\344\223\002&\022$/cosmos/bank/v1beta1/supply/by_denom'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\035\022\033/cosmos/bank/v1beta1/params'
  _globals['_QUERY'].methods_by_name['DenomMetadata']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomMetadata']._serialized_options = b'\210\347\260*\001\202\323\344\223\002.\022,/cosmos/bank/v1beta1/denoms_metadata/{denom}'
  _globals['_QUERY'].methods_by_name['DenomMetadataByQueryString']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomMetadataByQueryString']._serialized_options = b'\210\347\260*\001\202\323\344\223\0026\0224/cosmos/bank/v1beta1/denoms_metadata_by_query_string'
  _globals['_QUERY'].methods_by_name['DenomsMetadata']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomsMetadata']._serialized_options = b'\210\347\260*\001\202\323\344\223\002&\022$/cosmos/bank/v1beta1/denoms_metadata'
  _globals['_QUERY'].methods_by_name['DenomOwners']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomOwners']._serialized_options = b'\210\347\260*\001\202\323\344\223\002+\022)/cosmos/bank/v1beta1/denom_owners/{denom}'
  _globals['_QUERY'].methods_by_name['SendEnabled']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SendEnabled']._serialized_options = b'\210\347\260*\001\202\323\344\223\002#\022!/cosmos/bank/v1beta1/send_enabled'
  _globals['_QUERYBALANCEREQUEST']._serialized_start=291
  _globals['_QUERYBALANCEREQUEST']._serialized_end=380
  _globals['_QUERYBALANCERESPONSE']._serialized_start=382
  _globals['_QUERYBALANCERESPONSE']._serialized_end=448
  _globals['_QUERYALLBALANCESREQUEST']._serialized_start=451
  _globals['_QUERYALLBALANCESREQUEST']._serialized_end=612
  _globals['_QUERYALLBALANCESRESPONSE']._serialized_start=615
  _globals['_QUERYALLBALANCESRESPONSE']._serialized_end=819
  _globals['_QUERYSPENDABLEBALANCESREQUEST']._serialized_start=822
  _globals['_QUERYSPENDABLEBALANCESREQUEST']._serialized_end=966
  _globals['_QUERYSPENDABLEBALANCESRESPONSE']._serialized_start=969
  _globals['_QUERYSPENDABLEBALANCESRESPONSE']._serialized_end=1179
  _globals['_QUERYSPENDABLEBALANCEBYDENOMREQUEST']._serialized_start=1181
  _globals['_QUERYSPENDABLEBALANCEBYDENOMREQUEST']._serialized_end=1286
  _globals['_QUERYSPENDABLEBALANCEBYDENOMRESPONSE']._serialized_start=1288
  _globals['_QUERYSPENDABLEBALANCEBYDENOMRESPONSE']._serialized_end=1370
  _globals['_QUERYTOTALSUPPLYREQUEST']._serialized_start=1372
  _globals['_QUERYTOTALSUPPLYREQUEST']._serialized_end=1467
  _globals['_QUERYTOTALSUPPLYRESPONSE']._serialized_start=1470
  _globals['_QUERYTOTALSUPPLYRESPONSE']._serialized_end=1672
  _globals['_QUERYSUPPLYOFREQUEST']._serialized_start=1674
  _globals['_QUERYSUPPLYOFREQUEST']._serialized_end=1711
  _globals['_QUERYSUPPLYOFRESPONSE']._serialized_start=1713
  _globals['_QUERYSUPPLYOFRESPONSE']._serialized_end=1790
  _globals['_QUERYPARAMSREQUEST']._serialized_start=1792
  _globals['_QUERYPARAMSREQUEST']._serialized_end=1812
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=1814
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=1891
  _globals['_QUERYDENOMSMETADATAREQUEST']._serialized_start=1893
  _globals['_QUERYDENOMSMETADATAREQUEST']._serialized_end=1981
  _globals['_QUERYDENOMSMETADATARESPONSE']._serialized_start=1984
  _globals['_QUERYDENOMSMETADATARESPONSE']._serialized_end=2135
  _globals['_QUERYDENOMMETADATAREQUEST']._serialized_start=2137
  _globals['_QUERYDENOMMETADATAREQUEST']._serialized_end=2179
  _globals['_QUERYDENOMMETADATARESPONSE']._serialized_start=2181
  _globals['_QUERYDENOMMETADATARESPONSE']._serialized_end=2269
  _globals['_QUERYDENOMMETADATABYQUERYSTRINGREQUEST']._serialized_start=2271
  _globals['_QUERYDENOMMETADATABYQUERYSTRINGREQUEST']._serialized_end=2326
  _globals['_QUERYDENOMMETADATABYQUERYSTRINGRESPONSE']._serialized_start=2328
  _globals['_QUERYDENOMMETADATABYQUERYSTRINGRESPONSE']._serialized_end=2429
  _globals['_QUERYDENOMOWNERSREQUEST']._serialized_start=2431
  _globals['_QUERYDENOMOWNERSREQUEST']._serialized_end=2531
  _globals['_DENOMOWNER']._serialized_start=2533
  _globals['_DENOMOWNER']._serialized_end=2643
  _globals['_QUERYDENOMOWNERSRESPONSE']._serialized_start=2646
  _globals['_QUERYDENOMOWNERSRESPONSE']._serialized_end=2788
  _globals['_QUERYSENDENABLEDREQUEST']._serialized_start=2790
  _globals['_QUERYSENDENABLEDREQUEST']._serialized_end=2891
  _globals['_QUERYSENDENABLEDRESPONSE']._serialized_start=2894
  _globals['_QUERYSENDENABLEDRESPONSE']._serialized_end=3037
  _globals['_QUERY']._serialized_start=3040
  _globals['_QUERY']._serialized_end=5103
# @@protoc_insertion_point(module_scope)



from v4_proto.tendermint.abci import types_pb2 as _types_pb2
from v4_proto.cosmos.store.v1beta1 import listening_pb2 as _listening_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListenFinalizeBlockRequest(_message.Message):
    __slots__ = ("req", "res")
    REQ_FIELD_NUMBER: _ClassVar[int]
    RES_FIELD_NUMBER: _ClassVar[int]
    req: _types_pb2.RequestFinalizeBlock
    res: _types_pb2.ResponseFinalizeBlock
    def __init__(self, req: _Optional[_Union[_types_pb2.RequestFinalizeBlock, _Mapping]] = ..., res: _Optional[_Union[_types_pb2.ResponseFinalizeBlock, _Mapping]] = ...) -> None: ...

class ListenFinalizeBlockResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListenCommitRequest(_message.Message):
    __slots__ = ("block_height", "res", "change_set")
    BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    RES_FIELD_NUMBER: _ClassVar[int]
    CHANGE_SET_FIELD_NUMBER: _ClassVar[int]
    block_height: int
    res: _types_pb2.ResponseCommit
    change_set: _containers.RepeatedCompositeFieldContainer[_listening_pb2.StoreKVPair]
    def __init__(self, block_height: _Optional[int] = ..., res: _Optional[_Union[_types_pb2.ResponseCommit, _Mapping]] = ..., change_set: _Optional[_Iterable[_Union[_listening_pb2.StoreKVPair, _Mapping]]] = ...) -> None: ...

class ListenCommitResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/subaccounts/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/subaccounts/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$dydxprotocol/subaccounts/query.proto\x12\x18\x64ydxprotocol.subaccounts\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\"T\n\x19QueryGetSubaccountRequest\x12\'\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x0e\n\x06number\x18\x02 \x01(\r\"Y\n\x17QuerySubaccountResponse\x12>\n\nsubaccount\x18\x01 \x01(\x0b\x32$.dydxprotocol.subaccounts.SubaccountB\x04\xc8\xde\x1f\x00\"W\n\x19QueryAllSubaccountRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x99\x01\n\x1aQuerySubaccountAllResponse\x12>\n\nsubaccount\x18\x01 \x03(\x0b\x32$.dydxprotocol.subaccounts.SubaccountB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"H\n0QueryGetWithdrawalAndTransfersBlockedInfoRequest\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\"\xbc\x01\n1QueryGetWithdrawalAndTransfersBlockedInfoResponse\x12-\n%negative_tnc_subaccount_seen_at_block\x18\x01 \x01(\r\x12\"\n\x1a\x63hain_outage_seen_at_block\x18\x02 \x01(\r\x12\x34\n,withdrawals_and_transfers_unblocked_at_block\x18\x03 \x01(\r\"9\n!QueryCollateralPoolAddressRequest\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\"_\n\"QueryCollateralPoolAddressResponse\x12\x39\n\x17\x63ollateral_pool_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString2\xe2\x06\n\x05Query\x12\xb3\x01\n\nSubaccount\x12\x33.dydxprotocol.subaccounts.QueryGetSubaccountRequest\x1a\x31.dydxprotocol.subaccounts.QuerySubaccountResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/dydxprotocol/subaccounts/subaccount/{owner}/{number}\x12\xa8\x01\n\rSubaccountAll\x12\x33.dydxprotocol.subaccounts.QueryAllSubaccountRequest\x1a\x34.dydxprotocol.subaccounts.QuerySubaccountAllResponse\",\x82\xd3\xe4\x93\x02&\x12$/dydxprotocol/subaccounts/subaccount\x12\x98\x02\n$GetWithdrawalAndTransfersBlockedInfo\x12J.dydxprotocol.subaccounts.QueryGetWithdrawalAndTransfersBlockedInfoRequest\x1aK.dydxprotocol.subaccounts.QueryGetWithdrawalAndTransfersBlockedInfoResponse\"W\x82\xd3\xe4\x93\x02Q\x12O/dydxprotocol/subaccounts/withdrawals_and_transfers_blocked_info/{perpetual_id}\x12\xdc\x01\n\x15\x43ollateralPoolAddress\x12;.dydxprotocol.subaccounts.QueryCollateralPoolAddressRequest\x1a<.dydxprotocol.subaccounts.QueryCollateralPoolAddressResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/dydxprotocol/subaccounts/collateral_pool_address/{perpetual_id}B?Z=github.com/dydxprotocol/v4-chain/protocol/x/subaccounts/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.subaccounts.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dydxprotocol/v4-chain/protocol/x/subaccounts/types'
  _globals['_QUERYGETSUBACCOUNTREQUEST'].fields_by_name['owner']._loaded_options = None
  _globals['_QUERYGETSUBACCOUNTREQUEST'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYSUBACCOUNTRESPONSE'].fields_by_name['subaccount']._loaded_options = None
  _globals['_QUERYSUBACCOUNTRESPONSE'].fields_by_name['subaccount']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSUBACCOUNTALLRESPONSE'].fields_by_name['subaccount']._loaded_options = None
  _globals['_QUERYSUBACCOUNTALLRESPONSE'].fields_by_name['subaccount']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCOLLATERALPOOLADDRESSRESPONSE'].fields_by_name['collateral_pool_address']._loaded_options = None
  _globals['_QUERYCOLLATERALPOOLADDRESSRESPONSE'].fields_by_name['collateral_pool_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERY'].methods_by_name['Subaccount']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Subaccount']._serialized_options = b'\202\323\344\223\0027\0225/dydxprotocol/subaccounts/subaccount/{owner}/{number}'
  _globals['_QUERY'].methods_by_name['SubaccountAll']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountAll']._serialized_options = b'\202\323\344\223\002&\022$/dydxprotocol/subaccounts/subaccount'
  _globals['_QUERY'].methods_by_name['GetWithdrawalAndTransfersBlockedInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetWithdrawalAndTransfersBlockedInfo']._serialized_options = b'\202\323\344\223\002Q\022O/dydxprotocol/subaccounts/withdrawals_and_transfers_blocked_info/{perpetual_id}'
  _globals['_QUERY'].methods_by_name['CollateralPoolAddress']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CollateralPoolAddress']._serialized_options = b'\202\323\344\223\002B\022@/dydxprotocol/subaccounts/collateral_pool_address/{perpetual_id}'
  _globals['_QUERYGETSUBACCOUNTREQUEST']._serialized_start=232
  _globals['_QUERYGETSUBACCOUNTREQUEST']._serialized_end=316
  _globals['_QUERYSUBACCOUNTRESPONSE']._serialized_start=318
  _globals['_QUERYSUBACCOUNTRESPONSE']._serialized_end=407
  _globals['_QUERYALLSUBACCOUNTREQUEST']._serialized_start=409
  _globals['_QUERYALLSUBACCOUNTREQUEST']._serialized_end=496
  _globals['_QUERYSUBACCOUNTALLRESPONSE']._serialized_start=499
  _globals['_QUERYSUBACCOUNTALLRESPONSE']._serialized_end=652
  _globals['_QUERYGETWITHDRAWALANDTRANSFERSBLOCKEDINFOREQUEST']._serialized_start=654
  _globals['_QUERYGETWITHDRAWALANDTRANSFERSBLOCKEDINFOREQUEST']._serialized_end=726
  _globals['_QUERYGETWITHDRAWALANDTRANSFERSBLOCKEDINFORESPONSE']._serialized_start=729
  _globals['_QUERYGETWITHDRAWALANDTRANSFERSBLOCKEDINFORESPONSE']._serialized_end=917
  _globals['_QUERYCOLLATERALPOOLADDRESSREQUEST']._serialized_start=919
  _globals['_QUERYCOLLATERALPOOLADDRESSREQUEST']._serialized_end=976
  _globals['_QUERYCOLLATERALPOOLADDRESSRESPONSE']._serialized_start=978
  _globals['_QUERYCOLLATERALPOOLADDRESSRESPONSE']._serialized_end=1073
  _globals['_QUERY']._serialized_start=1076
  _globals['_QUERY']._serialized_end=1942
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.tendermint.crypto import keys_pb2 as _keys_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BlockIDFlag(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    BLOCK_ID_FLAG_UNKNOWN: _ClassVar[BlockIDFlag]
    BLOCK_ID_FLAG_ABSENT: _ClassVar[BlockIDFlag]
    BLOCK_ID_FLAG_COMMIT: _ClassVar[BlockIDFlag]
    BLOCK_ID_FLAG_NIL: _ClassVar[BlockIDFlag]
BLOCK_ID_FLAG_UNKNOWN: BlockIDFlag
BLOCK_ID_FLAG_ABSENT: BlockIDFlag
BLOCK_ID_FLAG_COMMIT: BlockIDFlag
BLOCK_ID_FLAG_NIL: BlockIDFlag

class ValidatorSet(_message.Message):
    __slots__ = ("validators", "proposer", "total_voting_power")
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_FIELD_NUMBER: _ClassVar[int]
    TOTAL_VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    validators: _containers.RepeatedCompositeFieldContainer[Validator]
    proposer: Validator
    total_voting_power: int
    def __init__(self, validators: _Optional[_Iterable[_Union[Validator, _Mapping]]] = ..., proposer: _Optional[_Union[Validator, _Mapping]] = ..., total_voting_power: _Optional[int] = ...) -> None: ...

class Validator(_message.Message):
    __slots__ = ("address", "pub_key", "voting_power", "proposer_priority")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_PRIORITY_FIELD_NUMBER: _ClassVar[int]
    address: bytes
    pub_key: _keys_pb2.PublicKey
    voting_power: int
    proposer_priority: int
    def __init__(self, address: _Optional[bytes] = ..., pub_key: _Optional[_Union[_keys_pb2.PublicKey, _Mapping]] = ..., voting_power: _Optional[int] = ..., proposer_priority: _Optional[int] = ...) -> None: ...

class SimpleValidator(_message.Message):
    __slots__ = ("pub_key", "voting_power")
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    VOTING_POWER_FIELD_NUMBER: _ClassVar[int]
    pub_key: _keys_pb2.PublicKey
    voting_power: int
    def __init__(self, pub_key: _Optional[_Union[_keys_pb2.PublicKey, _Mapping]] = ..., voting_power: _Optional[int] = ...) -> None: ...



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import any_pb2 as _any_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetRequest(_message.Message):
    __slots__ = ("message_name", "index", "values")
    MESSAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    message_name: str
    index: str
    values: _containers.RepeatedCompositeFieldContainer[IndexValue]
    def __init__(self, message_name: _Optional[str] = ..., index: _Optional[str] = ..., values: _Optional[_Iterable[_Union[IndexValue, _Mapping]]] = ...) -> None: ...

class GetResponse(_message.Message):
    __slots__ = ("result",)
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: _any_pb2.Any
    def __init__(self, result: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class ListRequest(_message.Message):
    __slots__ = ("message_name", "index", "prefix", "range", "pagination")
    class Prefix(_message.Message):
        __slots__ = ("values",)
        VALUES_FIELD_NUMBER: _ClassVar[int]
        values: _containers.RepeatedCompositeFieldContainer[IndexValue]
        def __init__(self, values: _Optional[_Iterable[_Union[IndexValue, _Mapping]]] = ...) -> None: ...
    class Range(_message.Message):
        __slots__ = ("start", "end")
        START_FIELD_NUMBER: _ClassVar[int]
        END_FIELD_NUMBER: _ClassVar[int]
        start: _containers.RepeatedCompositeFieldContainer[IndexValue]
        end: _containers.RepeatedCompositeFieldContainer[IndexValue]
        def __init__(self, start: _Optional[_Iterable[_Union[IndexValue, _Mapping]]] = ..., end: _Optional[_Iterable[_Union[IndexValue, _Mapping]]] = ...) -> None: ...
    MESSAGE_NAME_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    PREFIX_FIELD_NUMBER: _ClassVar[int]
    RANGE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    message_name: str
    index: str
    prefix: ListRequest.Prefix
    range: ListRequest.Range
    pagination: _pagination_pb2.PageRequest
    def __init__(self, message_name: _Optional[str] = ..., index: _Optional[str] = ..., prefix: _Optional[_Union[ListRequest.Prefix, _Mapping]] = ..., range: _Optional[_Union[ListRequest.Range, _Mapping]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class ListResponse(_message.Message):
    __slots__ = ("results", "pagination")
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, results: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class IndexValue(_message.Message):
    __slots__ = ("uint", "int", "str", "bytes", "enum", "bool", "timestamp", "duration")
    UINT_FIELD_NUMBER: _ClassVar[int]
    INT_FIELD_NUMBER: _ClassVar[int]
    STR_FIELD_NUMBER: _ClassVar[int]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    ENUM_FIELD_NUMBER: _ClassVar[int]
    BOOL_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    uint: int
    int: int
    str: str
    bytes: bytes
    enum: str
    bool: bool
    timestamp: _timestamp_pb2.Timestamp
    duration: _duration_pb2.Duration
    def __init__(self, uint: _Optional[int] = ..., int: _Optional[int] = ..., str: _Optional[str] = ..., bytes: _Optional[bytes] = ..., enum: _Optional[str] = ..., bool: bool = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...



import datetime

from v4_proto.dydxprotocol.indexer.shared import removal_reason_pb2 as _removal_reason_pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import clob_pb2 as _clob_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OrderPlaceV1(_message.Message):
    __slots__ = ("order", "placement_status", "time_stamp")
    class OrderPlacementStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ORDER_PLACEMENT_STATUS_UNSPECIFIED: _ClassVar[OrderPlaceV1.OrderPlacementStatus]
        ORDER_PLACEMENT_STATUS_BEST_EFFORT_OPENED: _ClassVar[OrderPlaceV1.OrderPlacementStatus]
        ORDER_PLACEMENT_STATUS_OPENED: _ClassVar[OrderPlaceV1.OrderPlacementStatus]
    ORDER_PLACEMENT_STATUS_UNSPECIFIED: OrderPlaceV1.OrderPlacementStatus
    ORDER_PLACEMENT_STATUS_BEST_EFFORT_OPENED: OrderPlaceV1.OrderPlacementStatus
    ORDER_PLACEMENT_STATUS_OPENED: OrderPlaceV1.OrderPlacementStatus
    ORDER_FIELD_NUMBER: _ClassVar[int]
    PLACEMENT_STATUS_FIELD_NUMBER: _ClassVar[int]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    order: _clob_pb2.IndexerOrder
    placement_status: OrderPlaceV1.OrderPlacementStatus
    time_stamp: _timestamp_pb2.Timestamp
    def __init__(self, order: _Optional[_Union[_clob_pb2.IndexerOrder, _Mapping]] = ..., placement_status: _Optional[_Union[OrderPlaceV1.OrderPlacementStatus, str]] = ..., time_stamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class OrderRemoveV1(_message.Message):
    __slots__ = ("removed_order_id", "reason", "removal_status", "time_stamp")
    class OrderRemovalStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ORDER_REMOVAL_STATUS_UNSPECIFIED: _ClassVar[OrderRemoveV1.OrderRemovalStatus]
        ORDER_REMOVAL_STATUS_BEST_EFFORT_CANCELED: _ClassVar[OrderRemoveV1.OrderRemovalStatus]
        ORDER_REMOVAL_STATUS_CANCELED: _ClassVar[OrderRemoveV1.OrderRemovalStatus]
        ORDER_REMOVAL_STATUS_FILLED: _ClassVar[OrderRemoveV1.OrderRemovalStatus]
    ORDER_REMOVAL_STATUS_UNSPECIFIED: OrderRemoveV1.OrderRemovalStatus
    ORDER_REMOVAL_STATUS_BEST_EFFORT_CANCELED: OrderRemoveV1.OrderRemovalStatus
    ORDER_REMOVAL_STATUS_CANCELED: OrderRemoveV1.OrderRemovalStatus
    ORDER_REMOVAL_STATUS_FILLED: OrderRemoveV1.OrderRemovalStatus
    REMOVED_ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    REMOVAL_STATUS_FIELD_NUMBER: _ClassVar[int]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    removed_order_id: _clob_pb2.IndexerOrderId
    reason: _removal_reason_pb2.OrderRemovalReason
    removal_status: OrderRemoveV1.OrderRemovalStatus
    time_stamp: _timestamp_pb2.Timestamp
    def __init__(self, removed_order_id: _Optional[_Union[_clob_pb2.IndexerOrderId, _Mapping]] = ..., reason: _Optional[_Union[_removal_reason_pb2.OrderRemovalReason, str]] = ..., removal_status: _Optional[_Union[OrderRemoveV1.OrderRemovalStatus, str]] = ..., time_stamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class OrderUpdateV1(_message.Message):
    __slots__ = ("order_id", "total_filled_quantums")
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FILLED_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    order_id: _clob_pb2.IndexerOrderId
    total_filled_quantums: int
    def __init__(self, order_id: _Optional[_Union[_clob_pb2.IndexerOrderId, _Mapping]] = ..., total_filled_quantums: _Optional[int] = ...) -> None: ...

class OrderReplaceV1(_message.Message):
    __slots__ = ("old_order_id", "order", "placement_status", "time_stamp")
    OLD_ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    PLACEMENT_STATUS_FIELD_NUMBER: _ClassVar[int]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    old_order_id: _clob_pb2.IndexerOrderId
    order: _clob_pb2.IndexerOrder
    placement_status: OrderPlaceV1.OrderPlacementStatus
    time_stamp: _timestamp_pb2.Timestamp
    def __init__(self, old_order_id: _Optional[_Union[_clob_pb2.IndexerOrderId, _Mapping]] = ..., order: _Optional[_Union[_clob_pb2.IndexerOrder, _Mapping]] = ..., placement_status: _Optional[_Union[OrderPlaceV1.OrderPlacementStatus, str]] = ..., time_stamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class OffChainUpdateV1(_message.Message):
    __slots__ = ("order_place", "order_remove", "order_update", "order_replace")
    ORDER_PLACE_FIELD_NUMBER: _ClassVar[int]
    ORDER_REMOVE_FIELD_NUMBER: _ClassVar[int]
    ORDER_UPDATE_FIELD_NUMBER: _ClassVar[int]
    ORDER_REPLACE_FIELD_NUMBER: _ClassVar[int]
    order_place: OrderPlaceV1
    order_remove: OrderRemoveV1
    order_update: OrderUpdateV1
    order_replace: OrderReplaceV1
    def __init__(self, order_place: _Optional[_Union[OrderPlaceV1, _Mapping]] = ..., order_remove: _Optional[_Union[OrderRemoveV1, _Mapping]] = ..., order_update: _Optional[_Union[OrderUpdateV1, _Mapping]] = ..., order_replace: _Optional[_Union[OrderReplaceV1, _Mapping]] = ...) -> None: ...
